;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "lem" "0.24"
  "A lemmy client."
  '((emacs         "29.1")
    (fedi          "0.2")
    (markdown-mode "2.5"))
  :url "https://codeberg.org/martianh/lem.el"
  :commit "a0f4fa89fe73dfe7412f5d25d6e0619abf8cff14"
  :revdesc "a0f4fa89fe73"
  :keywords '("multimedia" "comm" "web" "fediverse")
  :authors '(("martian hiatus" . "mousebot@disroot.org"))
  :maintainers '(("martian hiatus" . "mousebot@disroot.org")))
